_antonyms = {
    "vermogen": "onvermogen",
    "abnormaal": "normaal",
    "afschaffen": "tot stand brengen",
    "afwezigheid": "aanwezigheid",
    "afwezig": "aanwezig",
    "toekomst": "verleden",
    "absoluut": "familielid",
    "zich onthouden": "consumeren",
    "abstract": "beton",
    "overvloed": "schaarste",
    "overvloedig": "schaars",
    "aanvaarden": "afwijzen",
    "toegeven": "ontkennen",
    "aanvaardbaar": "niet aanvaardbaar",
    "aanvaarding": "afwijzing",
    "beschikbaar": "ontoegankelijk",
    "accuraat": "onnauwkeurig",
    "erkend": "niet erkend",
    "kennis": "vreemdeling",
    "handelen": "refrein",
    "actie": "werkeloosheid",
    "actief": "rustig",
    "bestaand": "niet bestaand",
    "luidruchtig": "rustig",
    "activiteit": "inactiviteit",
    "werkelijk": "potentieel",
    "toevoegen": "aftrekken",
    "toevoeging": "aftrekking",
    "voldoende": "onvoldoende",
    "bijvoeglijk naamwoord": "substantief",
    "toelaatbaar": "ontoelaatbaar",
    "volwassen": "jeugdig",
    "van te voren": "achteruitgaan",
    "verder": "terug",
    "voorkant": "achterkant",
    "veer": "terug",
    "voordeel": "nadeel",
    "bevestiging": "omkering",
    "bevestigend": "negatief",
    "neutrale": "negatief",
    "achteruit": "voor-",
    "leeftijd": "verjongen",
    "oud": "jong",
    "agitatie": "rust",
    "mee eens": "het oneens zijn",
    "aangenaam": "onplezierig",
    "overeenkomst": "meningsverschil",
    "gewijzigd": "ongewijzigd",
    "afwisselend": "tegenover",
    "amateur": "professioneel",
    "dubbelzinnig": "ondubbelzinnig",
    "minnelijk": "vijandig",
    "vriendelijk": "onvriendelijk",
    "amfibisch": "aards",
    "anaal": "mondeling",
    "analoog": "homoloog",
    "analyse": "synthese",
    "analytisch": "synthetisch",
    "voorvader": "afstammeling",
    "hoekig": "afgeronde",
    "bezielen": "levenloos",
    "antwoord": "vraag",
    "vijandig": "vriendelijk",
    "antecedent": "volgend",
    "voorste": "zitvlak",
    "antiseptisch": "septisch",
    "uiterlijk": "verdwijning",
    "waardering": "waardevermindering",
    "goedkeuring": "afkeuring",
    "goedkeuren": "afkeuren",
    "aquatisch": "amfibisch",
    "aards": "hemels",
    "waterig": "vuur-",
    "arm": "ontwapenen",
    "gewapend": "ongewapend",
    "aankomen": "het verlof",
    "opstijgen": "neerdalen",
    "beklimming": "afdaling",
    "in slaap": "wakker",
    "instemming": "van mening",
    "asymmetrie": "symmetrie",
    "atheïsme": "theïsme",
    "hechten": "losmaken",
    "aanval": "verdedigen",
    "vervolgen": "verdedigen",
    "aandacht": "onoplettendheid",
    "aantrekkelijkheid": "afstoting",
    "hoorbaar": "onhoorbaar",
    "vermeerdering": "vermindering",
    "tante": "oom",
    "gemachtigde": "onbevoegd",
    "automatisch": "handboek",
    "vermijden": "confronteren",
    "wakker": "in slaap",
    "terug": "veer",
    "achteruitgaan": "van te voren",
    "achterkant": "hoofd",
    "achtergrond": "voorgrond",
    "achterwaarts": "vooruit",
    "omgekeerde": "voorzijde",
    "slecht": "deugdzaam",
    "onheil": "goed",
    "slechtheid": "goedheid",
    "evenwichtige": "onevenwichtig",
    "beer": "bul",
    "mooi": "lelijk",
    "schoonheid": "lelijkheid",
    "beginnen": "einde",
    "begin": "hou op",
    "vroeg": "laat",
    "geloof": "ongeloof",
    "bocht": "strekken",
    "goedaardig": "kwaadaardig",
    "groot": "mineur",
    "geboorte": "dood",
    "biseksueel": "homoseksueel",
    "zwart": "wit",
    "zegenen": "vloek",
    "gezegend": "vervloekt",
    "bloedeloos": "bloedig",
    "bloedig": "bloedeloos",
    "vervagen": "focus",
    "koken": "bevriezen",
    "stoutmoedig": "timide",
    "vrijmoedigheid": "schroom",
    "lenen": "lenen",
    "lener": "geldschieter",
    "bodem": "top",
    "gebonden": "ongebonden",
    "jongen": "meisje",
    "boycot": "begunstigen",
    "breken": "reparatie",
    "breekbaar": "onbreekbaar",
    "opvrolijken": "verduisteren",
    "verlichten": "verduisteren",
    "gebroken": "ongebroken",
    "broer": "zus",
    "bul": "beer",
    "bezig": "nutteloos",
    "werk": "nutteloos",
    "kopen": "verkopen",
    "kalmte": "stormachtig",
    "rust": "agitatie",
    "in staat": "onbekwaam",
    "capaciteit": "onbekwaamheid",
    "contant geld": "credit",
    "debiteren": "credit",
    "centrum": "links",
    "hersen-": "emotioneel",
    "zekerheid": "onzekerheid",
    "verandering": "verblijf",
    "vertrekken": "verblijf",
    "verhuizing": "verblijf",
    "veranderlijk": "onveranderlijk",
    "veranderd": "onveranderd",
    "in rekening brengen": "ontlading",
    "aanwerven": "ontlading",
    "goedkoop": "duur",
    "juichen": "klagen",
    "vrolijk": "deprimerend",
    "kind": "ouder",
    "civiel": "leger",
    "vordering": "verbeuren",
    "helderheid": "ondoorzichtigheid",
    "uitsteeksel": "duisternis",
    "transparantie": "ondoorzichtigheid",
    "schoon": "onrein",
    "geestelijkheid": "de leken",
    "geestelijke": "leek",
    "dichtbij": "open",
    "gesloten": "open",
    "gesloten": "open",
    "geslotenheid": "openheid",
    "kust-": "binnenlands",
    "samenhangend": "onsamenhangend",
    "koude": "warm",
    "onderpand": "lineal",
    "komedie": "tragedie",
    "comfort": "ongemak",
    "gemeenschappelijk": "ongewoon",
    "verenigbaar": "onverenigbaar",
    "bevoegdheid": "onbekwaamheid",
    "competent": "onbekwaam",
    "wedstrijd": "samenwerking",
    "klagen": "juichen",
    "volledigheid": "onvolledigheid",
    "complex": "eenvoudig",
    "samenstelling": "eenvoudig",
    "compliant": "uitdagend",
    "compliceren": "makkelijker maken",
    "concaaf": "convex",
    "verwaandheid": "nederigheid",
    "trots": "vernederen",
    "concentratie": "distributie",
    "concentrisch": "excentriek",
    "opvatting": "misvatting",
    "bezorgd": "onbekommerd",
    "beton": "abstract",
    "bevestigd": "niet bevestigd",
    "confronteren": "vermijden",
    "verbindend": "gescheidenheid",
    "aansluiten": "loskoppelen",
    "verbonden": "niet verbonden",
    "bewustzijn": "bewusteloosheid",
    "conservatief": "liberaal",
    "conserveren": "verspilling",
    "attent": "onbezonnen",
    "consistentie": "tegenstrijdigheid",
    "medeklinker": "klinker",
    "opvallend": "onopvallende",
    "grondwettelijk": "ongrondwettig",
    "consumeren": "zich onthouden",
    "inhoud": "ontevredenheid",
    "voortdurend": "sporadisch",
    "voortzetting": "staking",
    "doorgaan met": "staken",
    "continuïteit": "discontinuïteit",
    "doorlopend": "onderbreking",
    "contract": "uitbreiden",
    "gecontracteerd": "uitgebreid",
    "samentrekking": "uitbreiding",
    "geschikt": "lastig",
    "conventioneel": "onconventionele",
    "convergeren": "afwijken",
    "convergentie": "afwijking",
    "convergerend": "afwijkend",
    "convex": "concaaf",
    "overtuigd": "niet overtuigd",
    "koel": "warmte",
    "samenwerking": "wedstrijd",
    "kosmopolitisch": "provinciaal",
    "moed": "lafheid",
    "deksel": "ontdekken",
    "verborgen": "openlijk",
    "lafheid": "moed",
    "credit": "debiteren",
    "schuldeiser": "schuldenaar",
    "bekritiseren": "lof",
    "huilen": "lach",
    "uithardbare": "ongeneeslijke",
    "vloek": "zegenen",
    "vervloekt": "gezegend",
    "gebogen": "recht",
    "besnoeiing": "ongesneden",
    "gevaar": "veiligheid",
    "gevaarlijk": "veilig",
    "donker": "licht",
    "verduisteren": "verlichten",
    "duisternis": "uitsteeksel",
    "zwaarte": "lichtheid",
    "dochter": "zoon",
    "dag": "nacht",
    "doof": "gehoor",
    "dood": "geboorte",
    "schuldenaar": "schuldeiser",
    "fatsoen": "onfatsoenlijkheid",
    "fatsoenlijk": "onfatsoenlijk",
    "loof": "evergreen",
    "besluit": "besluiteloosheid",
    "beslissend": "besluiteloos",
    "afwijzen": "aanvaarden",
    "kleiner worden": "toename",
    "verminderde": "is gestegen",
    "decrement": "aanwas",
    "nederlaag": "zege",
    "verdedigen": "vervolgen",
    "verweerder": "eiser",
    "verdediging": "vervolging",
    "defensief": "aanvallend",
    "uitdagend": "compliant",
    "tekort": "lood",
    "bepaald": "onbepaald",
    "deflatie": "inflatie",
    "vertraging": "stormloop",
    "rondhangen": "stormloop",
    "vraag naar": "levering",
    "ontkennen": "toegeven",
    "afhankelijk": "onafhankelijk",
    "storting": "terugtrekken",
    "waardevermindering": "waardering",
    "deprimerend": "vrolijk",
    "neerdalen": "opstijgen",
    "afstammeling": "voorvader",
    "afdaling": "beklimming",
    "beschrijvend": "voorschrijvend",
    "wenselijk": "ongewenst",
    "wanhoop": "hoop",
    "ten einde raad": "hoop",
    "vernietigd": "bewaard",
    "losmaken": "binden",
    "devolutie": "evolutie",
    "verschillen": "gelijk",
    "ongelijk": "soortgelijk",
    "verschil": "gelijkheid",
    "moeilijk": "gemakkelijk",
    "ongemakkelijk": "gemakkelijk",
    "moeilijkheid": "gemak",
    "ijverig": "nalatig",
    "verdunning": "concentratie",
    "distributie": "concentratie",
    "vermindering": "vermeerdering",
    "vuil": "schoon",
    "onrein": "schoon",
    "onbruikbaar maken": "in staat stellen",
    "nadeel": "voordeel",
    "het oneens zijn": "mee eens",
    "onaangenaam": "aangenaam",
    "meningsverschil": "overeenkomst",
    "verdwijning": "uiterlijk",
    "afkeuring": "goedkeuring",
    "afkeuren": "goedkeuren",
    "ontwapenen": "arm",
    "ontlading": "aanwerven",
    "verbeuren": "vordering",
    "ongemak": "comfort",
    "loskoppelen": "aansluiten",
    "ontevredenheid": "tevredenheid",
    "staking": "voortzetting",
    "staken": "doorgaan met",
    "discontinuïteit": "continuïteit",
    "onderbreking": "doorlopend",
    "ontmoedigen": "aanmoedigen",
    "ontmoediging": "aanmoediging",
    "oneerlijk": "eerlijk",
    "oneerlijkheid": "eerlijkheid",
    "onteren": "eer",
    "desinfecteren": "infecteren",
    "uit elkaar vallen": "integreren",
    "gescheidenheid": "verbindend",
    "afkeer": "leuk vinden",
    "verjagen": "loge",
    "ongehoorzaamheid": "gehoorzaamheid",
    "ongehoorzaam": "gehoorzaam",
    "niet gehoorzamen": "gehoorzamen",
    "wanorde": "bestellen",
    "wanordelijk": "ordelijk",
    "ongeorganiseerd": "georganiseerd",
    "ongeorganiseerde": "georganiseerd",
    "niet tevreden": "verheugd",
    "weerleggen": "bewijzen",
    "diskwalificeren": "kwalificeren",
    "berucht": "achtenswaardig",
    "schande": "reputatie",
    "oneerbiedigheid": "eerbied",
    "oneerbiedig": "eerbiedig",
    "van mening": "instemming",
    "ondienst": "service",
    "dissonant": "harmonie",
    "afraden": "overhalen",
    "distale": "proximale",
    "afgelegen": "dichtbij",
    "open": "gesloten",
    "te onderscheiden": "niet te onderscheiden",
    "wantrouwen": "vertrouwen",
    "dag-": "nachtelijk",
    "afwijken": "convergeren",
    "afwijking": "convergentie",
    "afwijkend": "convergerend",
    "verdelen": "verenigen",
    "afzonderlijk": "vermenigvuldigen",
    "verdeeld": "verenigd",
    "deelbaar": "ondeelbaar",
    "huiselijk": "buitenlands",
    "inheems": "buitenlands",
    "dominant": "ondergeschikt",
    "slapend": "actief",
    "uitgestorven": "bestaand",
    "inactief": "actief",
    "passief": "actief",
    "rustig": "veelbewogen",
    "dubbele": "single",
    "meerdere": "single",
    "duif": "havik",
    "dramatisch": "lyrisch",
    "droog": "nat",
    "zuur": "veraangenamen",
    "ten gevolge": "overdreven",
    "dof": "verscherpen",
    "vlakken": "verscherpen",
    "stervende": "ontluikend",
    "gemak": "moeilijkheid",
    "gemakkelijk": "ongemakkelijk",
    "eb": "tij",
    "excentriek": "concentrisch",
    "geleerd": "onopgevoed",
    "effectief": "niet effectief",
    "rendement": "ondoeltreffendheid",
    "doeltreffend": "buiten werking",
    "uitgang": "toegang",
    "elastisch": "inelastisch",
    "in aanmerking komende": "niet in aanmerking komen",
    "emotioneel": "hersen-",
    "empirisch": "theoretisch",
    "leegte": "volheid",
    "leeg": "vol",
    "dun": "verdikken",
    "in staat stellen": "onbruikbaar maken",
    "aanmoedigen": "ontmoedigen",
    "aanmoediging": "ontmoediging",
    "einde": "begin",
    "midden-": "vroeg",
    "endemisch": "kosmopolitisch",
    "provinciaal": "kosmopolitisch",
    "energiek": "slaperig",
    "afdwingen": "vrijgesteld",
    "bezighouden": "losmaken",
    "genieten": "lijden",
    "invoeren": "uitgang",
    "gelijk": "ongelijk",
    "gelijkheid": "verschil",
    "equatoriaal": "polair",
    "billijk": "onbillijk",
    "wissen": "record",
    "tot stand brengen": "afschaffen",
    "veelbewogen": "rustig",
    "evergreen": "loof",
    "evolutie": "devolutie",
    "uitsluiting": "inclusie",
    "vrijgesteld": "afdwingen",
    "uitademen": "inademen",
    "uitgang": "invoeren",
    "uitbreiden": "contract",
    "uitgebreid": "gecontracteerd",
    "uitbreiding": "buiging",
    "verwacht": "niet verwacht",
    "duur": "goedkoop",
    "ervaren": "onervaren",
    "exporteren": "importeren",
    "uitdrukken": "lokaal",
    "algemeen": "specifiek",
    "nationaal": "internationale",
    "buitenkant": "interieur",
    "extern": "intern",
    "uitwendig": "inwendig",
    "doven": "ontbranden",
    "extramurale": "intramurale",
    "buitengewoon": "gewoon",
    "extrinsieke": "wezenlijk",
    "tekortkoming": "voorbijgaand",
    "lopend": "staand",
    "mislukking": "succes",
    "eerlijk": "oneerlijk",
    "getrouw": "ontrouw",
    "vallen": "stijgen",
    "reeks": "stijgen",
    "feilbaar": "onfeilbaar",
    "vallend": "stijgende lijn",
    "leugen": "waarheid",
    "valsheid": "waarheid",
    "roem": "schanddaad",
    "vertrouwd": "onbekend",
    "zin in hebben": "vlakte",
    "dik": "dun",
    "vol": "leeg",
    "verdikken": "dun",
    "vader": "moeder",
    "fauna": "flora",
    "gunstig": "ongunstig",
    "federaal": "unitaire",
    "vrouw": "mannetje",
    "vrouwelijk": "onzijdig",
    "vrouwelijkheid": "mannelijkheid",
    "vruchtbaar": "steriel",
    "trouw": "ontrouw",
    "figuur": "grond",
    "vullen": "leeg",
    "vind": "verliezen",
    "af hebben": "begin",
    "hou op": "begin",
    "eindige": "eindeloos",
    "brand": "huren",
    "buiging": "uitbreiding",
    "vlotter": "wastafel",
    "bron": "wastafel",
    "flora": "fauna",
    "focus": "vervagen",
    "vijand": "vriend",
    "vouwen": "ontvouwen",
    "volgen": "voorafgaan",
    "slagen": "voorafgaande",
    "volgeling": "leider",
    "dwaasheid": "wijsheid",
    "dwaas": "wijs",
    "voet": "hoofd",
    "staart": "hoofd",
    "verbieden": "toestaan",
    "voor-": "achteruit",
    "voorgrond": "achtergrond",
    "buitenlands": "inheems",
    "vergeten": "onthouden",
    "vergevensgezind": "onverzoenlijk",
    "formalisme": "imitatie",
    "gelukkig": "ongelukkig",
    "vooruit": "omgekeerde",
    "voorzijde": "omgekeerde",
    "vals": "eerlijk",
    "gevonden": "verloren",
    "broederlijk": "identiek",
    "bevriezen": "koken",
    "veelvuldig": "zeldzaam",
    "vaak": "zeldzaam",
    "vriend": "vijand",
    "hoofd": "staart",
    "volheid": "leegte",
    "functioneel": "biologisch",
    "anorganisch": "biologisch",
    "krijgen": "verlies",
    "gas-": "solide",
    "hol": "solide",
    "verzamelen": "verspreiding",
    "algemeenheid": "bijzonderheid",
    "genereus": "gierig",
    "meisje": "jongen",
    "goed": "onheil",
    "goedheid": "slechtheid",
    "geleidelijk": "plotseling",
    "dankbaar": "ondankbaar",
    "groter": "minder",
    "groen": "rijp",
    "bruto": "netto-",
    "grond": "figuur",
    "schuld": "onschuld",
    "schuldig": "onschuldig",
    "geluk": "ongelukkigheid",
    "hardheid": "zachtheid",
    "loudness": "zachtheid",
    "scherpte": "zachtheid",
    "harmonie": "dissonant",
    "een hekel hebben aan": "liefde",
    "hatelijk": "lief",
    "havik": "duif",
    "gezond": "ongezond",
    "gehoor": "doof",
    "warmte": "koel",
    "hemels": "aards",
    "heterogeniteit": "homogeniteit",
    "verbergen": "laten zien",
    "huren": "brand",
    "raken": "missen",
    "heilig": "ontheiligen",
    "homogeniteit": "heterogeniteit",
    "homoloog": "analoog",
    "homoseksueel": "biseksueel",
    "eerlijkheid": "oneerlijkheid",
    "eer": "onteren",
    "hoop": "wanhoop",
    "hoopvol": "hopeloos",
    "hopeloos": "hoopvol",
    "horizontaal": "verticaal",
    "onvriendelijk": "vriendelijk",
    "warm": "koude",
    "vernederen": "trots",
    "nederigheid": "trots",
    "hongerig": "dorstig",
    "identiek": "broederlijk",
    "nutteloos": "werk",
    "vuur-": "waterig",
    "ontbranden": "doven",
    "negeren": "kennisgeving",
    "onwettig": "rechtmatig",
    "onwettigheid": "wettigheid",
    "onleesbaar": "leesbaar",
    "onlogisch": "logisch",
    "imitatie": "formalisme",
    "onbelangrijk": "belangrijk",
    "onrijpheid": "rijpheid",
    "onmetelijk": "meetbaar",
    "onzedelijk": "moreel",
    "onzedelijkheid": "moraliteit",
    "onsterfelijk": "sterfelijk",
    "onsterfelijkheid": "sterfte",
    "onveranderlijk": "veranderlijk",
    "onpartijdigheid": "voorliefde",
    "onbegaanbaar": "begaanbaar",
    "ongeduld": "geduld",
    "ongeduldig": "geduldig",
    "onmerkbaar": "waarneembaar",
    "onvolmaaktheid": "perfectie",
    "ondoordringbaar": "doordringbaar",
    "ontoelaatbaar": "toelaatbaar",
    "onpersoonlijk": "persoonlijk",
    "onbeleefd": "beleefd",
    "importeren": "exporteren",
    "belangrijk": "onbelangrijk",
    "onmogelijkheid": "mogelijkheid",
    "onmachtig": "krachtig",
    "onwaarschijnlijk": "waarschijnlijk",
    "verbeterd": "onverbeterd",
    "verbetering": "afwijzen",
    "onvoorzichtig": "voorzichtig",
    "onzuiverheid": "puurheid",
    "onvermogen": "vermogen",
    "ontoegankelijk": "beschikbaar",
    "onnauwkeurig": "accuraat",
    "werkeloosheid": "actie",
    "inactiviteit": "activiteit",
    "ontoereikend": "voldoende",
    "levenloos": "bezielen",
    "onoplettendheid": "aandacht",
    "onhoorbaar": "hoorbaar",
    "onbekwaam": "competent",
    "onbekwaamheid": "bevoegdheid",
    "geneigd zijn": "horizontaal",
    "verticaal": "horizontaal",
    "inclusie": "uitsluiting",
    "onsamenhangend": "samenhangend",
    "onverenigbaar": "verenigbaar",
    "onvolledigheid": "volledigheid",
    "onbezonnen": "attent",
    "tegenstrijdigheid": "consistentie",
    "onopvallende": "opvallend",
    "lastig": "geschikt",
    "toename": "kleiner worden",
    "is gestegen": "verminderde",
    "aanwas": "decrement",
    "ongeneeslijke": "uithardbare",
    "onfatsoenlijkheid": "fatsoen",
    "onfatsoenlijk": "fatsoenlijk",
    "besluiteloosheid": "besluit",
    "besluiteloos": "beslissend",
    "onafhankelijk": "afhankelijk",
    "niet te onderscheiden": "te onderscheiden",
    "ondeelbaar": "deelbaar",
    "binnen-": "buitenshuis",
    "niet effectief": "effectief",
    "ondoeltreffendheid": "rendement",
    "inefficiënt": "doeltreffend",
    "inelastisch": "elastisch",
    "niet in aanmerking komen": "in aanmerking komende",
    "ongelijkheid": "gelijkheid",
    "onbillijk": "billijk",
    "onervaren": "ervaren",
    "onfeilbaar": "feilbaar",
    "schanddaad": "roem",
    "infecteren": "desinfecteren",
    "inferieur": "beter",
    "minderwaardigheid": "superioriteit",
    "ontrouw": "getrouw",
    "eindeloos": "eindige",
    "inflatie": "deflatie",
    "op de hoogte": "onwetend",
    "zeldzaam": "vaak",
    "toegang": "uitgang",
    "bewoond": "onbewoond",
    "inademen": "uitademen",
    "onrecht": "gerechtigheid",
    "binnenlands": "kust-",
    "onschuld": "schuld",
    "onschuldig": "schuldig",
    "onschadelijk": "schadelijk",
    "buiten werking": "doeltreffend",
    "krankzinnig": "verstandig",
    "krankzinnigheid": "geestelijke gezondheid",
    "onzekerheid": "zekerheid",
    "onbeduidendheid": "betekenis",
    "onoplosbaar": "oplosbaar",
    "insolventie": "solvabiliteit",
    "insolvent": "solvent",
    "onbestendigheid": "stabiliteit",
    "instrumentaal": "vocal",
    "ontoereikendheid": "voldoende hoeveelheid",
    "niet voldoende": "voldoende",
    "onvoldoende": "voldoende",
    "integreren": "uit elkaar vallen",
    "integratie": "segregatie",
    "intelligentie-": "domheid",
    "begrijpelijk": "onbegrijpelijk",
    "voorgenomen": "ongewild",
    "opzettelijk": "onopzettelijk",
    "geïnteresseerd": "niet geïnteresseerd",
    "interessant": "oninteressant",
    "interieur": "buitenkant",
    "tussen-": "terminal",
    "intern": "extern",
    "inwendig": "uitwendig",
    "internationale": "nationaal",
    "lokaal": "algemeen",
    "onverdraagzaamheid": "tolerantie",
    "onverdraagzaam": "verdraagzaam",
    "onhandelbaar": "handelbaar",
    "intramurale": "extramurale",
    "wezenlijk": "extrinsieke",
    "onzichtbaarheid": "zichtbaarheid",
    "onzichtbaar": "zichtbaar",
    "onwillekeurig": "vrijwillig",
    "irrationeel": "rationeel",
    "onregelmatig": "regelmatig",
    "onregelmatigheid": "regelmatigheid",
    "irrelevant": "relevant",
    "onverantwoordelijk": "verantwoordelijk",
    "kwestie": "terugroepen",
    "gewricht": "scheiden",
    "vreugde": "leed",
    "blijde": "treurig",
    "junior": "senior",
    "gerechtigheid": "onrecht",
    "jeugdig": "volwassen",
    "kern": "kern",
    "soort": "onaardig",
    "koning": "koningin",
    "de leken": "geestelijkheid",
    "laat": "vroeg",
    "lach": "huilen",
    "rechtmatig": "onwettig",
    "laks": "gespannen",
    "ontspannen": "gespannen",
    "leek": "geestelijke",
    "lood": "tekort",
    "leider": "volgeling",
    "het verlof": "aankomen",
    "links": "centrum",
    "wettelijk": "onwettig",
    "wettigheid": "onwettigheid",
    "legaliseren": "balling",
    "leesbaar": "onleesbaar",
    "geldschieter": "lener",
    "verlengen": "verkorten",
    "minder": "groter",
    "slaperig": "energiek",
    "niveau": "verhogen",
    "lager": "verhogen",
    "liberaal": "conservatief",
    "liggen": "stand",
    "opbrengst": "stand",
    "licht": "donker",
    "lichtheid": "zwaarte",
    "leuk vinden": "afkeer",
    "beperkt": "onbeperkt",
    "lineal": "onderpand",
    "vloeistof": "gas-",
    "solide": "hol",
    "specifiek": "algemeen",
    "plaats": "studio",
    "slot": "ontsluiten",
    "loge": "verjagen",
    "logisch": "onlogisch",
    "lang": "kort",
    "verliezen": "vind",
    "verlies": "krijgen",
    "verloren": "gevonden",
    "lief": "hatelijk",
    "liefde": "een hekel hebben aan",
    "lucky": "ongelukkig",
    "lyrisch": "dramatisch",
    "meerderheid": "minderheid",
    "maken": "breken",
    "reparatie": "breken",
    "mannetje": "vrouw",
    "kwaadaardig": "goedaardig",
    "handboek": "automatisch",
    "gemarkeerd": "ongemerkt",
    "getrouwd": "ongehuwd",
    "mannelijk": "vrouwelijk",
    "onzijdig": "vrouwelijk",
    "mannelijkheid": "vrouwelijkheid",
    "masker": "ontmaskeren",
    "materiaal": "onbelangrijk",
    "moederlijk": "vaderlijk",
    "rijpheid": "onrijpheid",
    "maximum": "minimum",
    "meetbaar": "onmetelijk",
    "geestelijk": "fysiek",
    "barmhartig": "meedogenloos",
    "meedogenloos": "barmhartig",
    "leger": "civiel",
    "geest": "vergeten",
    "onthouden": "vergeten",
    "minimum": "maximum",
    "mineur": "groot",
    "minderheid": "meerderheid",
    "misvatting": "opvatting",
    "missen": "raken",
    "kies": "moleculair",
    "moleculair": "kies",
    "moreel": "onzedelijk",
    "moraliteit": "onzedelijkheid",
    "sterfelijk": "onsterfelijk",
    "sterfte": "onsterfelijkheid",
    "moeder": "vader",
    "vermenigvuldigen": "afzonderlijk",
    "verenigen": "verdelen",
    "nadir": "zenit",
    "smal": "verbreden",
    "ontluikend": "stervende",
    "negatief": "neutrale",
    "nalatig": "ijverig",
    "neef": "nicht",
    "netto-": "bruto",
    "nicht": "neef",
    "nacht": "dag",
    "nachtelijk": "dag-",
    "nominaal": "echt",
    "onwerkelijk": "echt",
    "niet bestaand": "bestaand",
    "normaal": "abnormaal",
    "kennisgeving": "negeren",
    "schadelijk": "onschadelijk",
    "numeriek": "verbaal",
    "gehoorzaamheid": "ongehoorzaamheid",
    "gehoorzaam": "ongehoorzaam",
    "gehoorzamen": "niet gehoorzamen",
    "doelstelling": "subjectief",
    "verplicht": "facultatief",
    "schuin": "loodrecht",
    "ondoorzichtigheid": "transparantie",
    "bezet": "onbezet",
    "overtreding": "verdediging",
    "vervolging": "verdediging",
    "aanvallend": "defensief",
    "officieel": "officieus",
    "openheid": "geslotenheid",
    "gekant tegen": "zonder tegenstand",
    "tegenover": "afwisselend",
    "optimisme": "pessimisme",
    "optimist": "pessimist",
    "facultatief": "verplicht",
    "mondeling": "geschreven",
    "bestellen": "wanorde",
    "ordelijk": "wanordelijk",
    "gewoon": "buitengewoon",
    "biologisch": "anorganisch",
    "georganiseerd": "ongeorganiseerde",
    "orthodox": "onorthodoxe",
    "buitenshuis": "binnen-",
    "balling": "legaliseren",
    "overschatting": "onderschatten",
    "boven het hoofd": "oppervlakte",
    "openlijk": "verborgen",
    "pak": "uitpakken",
    "pijnlijk": "pijnloos",
    "pijnloos": "pijnlijk",
    "parallel": "schuin",
    "loodrecht": "schuin",
    "ouder": "kind",
    "voorliefde": "onpartijdigheid",
    "bijzonderheid": "algemeenheid",
    "gedeeltelijk": "geheel",
    "begaanbaar": "onbegaanbaar",
    "voorbijgaand": "lopend",
    "staand": "lopend",
    "verleden": "toekomst",
    "aanwezig": "afwezig",
    "vaderlijk": "moederlijk",
    "geduld": "ongeduld",
    "geduldig": "ongeduldig",
    "begunstigen": "boycot",
    "vrede": "oorlog",
    "boete": "beloning",
    "waarneembaar": "onmerkbaar",
    "perfectie": "onvolmaaktheid",
    "doordringbaar": "ondoordringbaar",
    "toegeeflijk": "preventieve",
    "toestaan": "verbieden",
    "persoonlijk": "onpersoonlijk",
    "overhalen": "afraden",
    "pessimisme": "optimisme",
    "pessimist": "optimist",
    "fysiek": "geestelijk",
    "vlakte": "zin in hebben",
    "eiser": "verweerder",
    "verheugd": "niet tevreden",
    "meervoud": "enkelvoud",
    "polair": "equatoriaal",
    "beleefd": "onbeleefd",
    "populair": "onpopulair",
    "poreusheid": "stevigheid",
    "mogelijkheid": "onmogelijkheid",
    "zitvlak": "voorste",
    "krachtig": "machteloos",
    "potentieel": "werkelijk",
    "armoede": "rijkdom",
    "machteloos": "krachtig",
    "lof": "bekritiseren",
    "voorafgaan": "slagen",
    "voorafgaande": "slagen",
    "voorvoegsel": "achtervoegsel",
    "voorbereiding": "resolutie",
    "bereid": "onvoorbereid",
    "voorschrijvend": "beschrijvend",
    "aanwezigheid": "afwezigheid",
    "bewaard": "vernietigd",
    "preventieve": "toegeeflijk",
    "primair": "tweede",
    "privaat": "openbaar",
    "privé": "in het openbaar",
    "waarschijnlijk": "onwaarschijnlijk",
    "produktief": "onproductieve",
    "ontheiligen": "heilig",
    "professioneel": "amateur",
    "vooruitgang": "regressie",
    "progressief": "regressieve",
    "aanstaande": "met terugwerkende kracht",
    "beschermde": "onbeschermd",
    "bewijzen": "weerleggen",
    "proximale": "distale",
    "naburig": "ultiem",
    "voorzichtig": "onvoorzichtig",
    "openbaar": "privaat",
    "in het openbaar": "privé",
    "gepubliceerd": "onuitgegeven",
    "trekken": "duwen",
    "nauwgezetheid": "traagheid",
    "zuivering": "rehabiliteren",
    "puurheid": "onzuiverheid",
    "duwen": "trekken",
    "kwalificeren": "diskwalificeren",
    "koningin": "koning",
    "vraag": "antwoord",
    "twijfelachtig": "onbetwistbaar",
    "snel": "langzaam",
    "verhogen": "lager",
    "rationeel": "irrationeel",
    "echt": "onwerkelijk",
    "realistisch": "onrealistische",
    "geruststellen": "zorgen",
    "terugroepen": "kwestie",
    "record": "wissen",
    "refrein": "handelen",
    "weigeren": "aanvaarden",
    "regressie": "vooruitgang",
    "regressieve": "progressief",
    "regelmatig": "onregelmatig",
    "regelmatigheid": "onregelmatigheid",
    "gereguleerd": "ongereguleerde",
    "rehabiliteren": "zuivering",
    "afwijzing": "aanvaarding",
    "verjongen": "leeftijd",
    "verwant": "niet verwant",
    "familielid": "absoluut",
    "relevant": "irrelevant",
    "betrouwbaar": "onbetrouwbaar",
    "religieus": "wereldlijk",
    "afstoting": "aantrekkelijkheid",
    "achtenswaardig": "berucht",
    "reputatie": "schande",
    "weerstand bieden": "overgave",
    "resolutie": "voorbereiding",
    "eerbied": "oneerbiedigheid",
    "eerbiedig": "oneerbiedig",
    "verantwoordelijk": "onverantwoordelijk",
    "terughoudend": "onbeperkt",
    "met terugwerkende kracht": "aanstaande",
    "omkering": "bevestiging",
    "beloning": "boete",
    "rijden": "lopen",
    "rijp": "groen",
    "stijgen": "reeks",
    "stijgende lijn": "vallend",
    "rotor": "stator",
    "ruwheid": "gladheid",
    "ronde": "plein",
    "afgeronde": "hoekig",
    "landelijk": "stedelijk",
    "stormloop": "rondhangen",
    "droevig": "gelukkig",
    "droefheid": "geluk",
    "ongelukkigheid": "geluk",
    "veilig": "gevaarlijk",
    "veiligheid": "onzekerheid",
    "verstandig": "krankzinnig",
    "geestelijke gezondheid": "krankzinnigheid",
    "tevredenheid": "ontevredenheid",
    "hartig": "onverkwikkelijk",
    "schaars": "overvloedig",
    "schaarste": "overvloed",
    "wetenschappelijk": "onwetenschappelijk",
    "scrupuleus": "gewetenloos",
    "tweede": "primair",
    "wereldlijk": "religieus",
    "segregatie": "integratie",
    "egoïstisch": "onzelfzuchtig",
    "verkopen": "kopen",
    "senior": "junior",
    "scheiden": "gewricht",
    "scheiding": "unie",
    "septisch": "antiseptisch",
    "service": "ondienst",
    "verrekend": "onbestendig",
    "verscherpen": "vlakken",
    "kort": "lang",
    "verkorten": "verlengen",
    "roepen": "fluisteren",
    "laten zien": "verbergen",
    "krimpen": "rekken",
    "kant": "bodem",
    "top": "bodem",
    "betekenis": "onbeduidendheid",
    "significant": "onbelangrijk",
    "soortgelijk": "ongelijk",
    "eenvoudig": "samenstelling",
    "makkelijker maken": "compliceren",
    "single": "meerdere",
    "enkelvoud": "meervoud",
    "wastafel": "bron",
    "zus": "broer",
    "slaap": "wekken",
    "langzaam": "snel",
    "klein": "groot",
    "gladheid": "ruwheid",
    "zachtheid": "scherpte",
    "stevigheid": "poreusheid",
    "oplosbaar": "onoplosbaar",
    "solvabiliteit": "insolventie",
    "solvent": "insolvent",
    "zoon": "dochter",
    "leed": "vreugde",
    "treurig": "blijde",
    "ongeschreven": "geschreven",
    "sporadisch": "voortdurend",
    "verspreiding": "verzamelen",
    "plein": "ronde",
    "stabiliteit": "onbestendigheid",
    "stal": "wankel",
    "stand": "opbrengst",
    "stator": "rotor",
    "verblijf": "verhuizing",
    "vast": "onvast",
    "steil": "geleidelijk",
    "plotseling": "geleidelijk",
    "steriel": "vruchtbaar",
    "stijven": "losmaken",
    "gierig": "genereus",
    "stormachtig": "kalmte",
    "recht": "gebogen",
    "strekken": "bocht",
    "vreemdeling": "kennis",
    "kracht": "zwakheid",
    "rekken": "krimpen",
    "sterk": "zwak",
    "studio": "plaats",
    "domheid": "intelligentie-",
    "subjectief": "doelstelling",
    "ondergeschikt": "dominant",
    "volgend": "antecedent",
    "substantief": "bijvoeglijk naamwoord",
    "aftrekken": "toevoegen",
    "aftrekking": "toevoeging",
    "succes": "mislukking",
    "geslaagd": "mislukt",
    "bezwijken": "overleven",
    "lijden": "genieten",
    "voldoende hoeveelheid": "ontoereikendheid",
    "achtervoegsel": "voorvoegsel",
    "zonsopkomst": "zonsondergang",
    "zonsondergang": "zonsopkomst",
    "beter": "inferieur",
    "superioriteit": "minderwaardigheid",
    "levering": "vraag naar",
    "ondersteunde": "niet gesteund",
    "oppervlakte": "boven het hoofd",
    "overgave": "weerstand bieden",
    "overleven": "bezwijken",
    "zoet": "zuur",
    "nat": "droog",
    "veraangenamen": "zuur",
    "symmetrie": "asymmetrie",
    "sympathiek": "niet sympathiek",
    "synergetische": "vijandig",
    "synthese": "analyse",
    "synthetisch": "analytisch",
    "traagheid": "nauwgezetheid",
    "smaakvol": "smaakloos",
    "lekker": "smaakloos",
    "smaakloos": "lekker",
    "inschrijving": "taai",
    "gespannen": "ontspannen",
    "terminal": "tussen-",
    "theïsme": "atheïsme",
    "theoretisch": "empirisch",
    "dorstig": "hongerig",
    "nadenkend": "gedachteloos",
    "gedachteloos": "nadenkend",
    "zuinig": "verkwistend",
    "tij": "eb",
    "binden": "losmaken",
    "timide": "stoutmoedig",
    "schroom": "vrijmoedigheid",
    "tolerantie": "onverdraagzaamheid",
    "verdraagzaam": "onverdraagzaam",
    "getand": "tandeloos",
    "tandeloos": "getand",
    "aangeraakt": "onaangeroerd",
    "taai": "inschrijving",
    "handelbaar": "onhandelbaar",
    "tragedie": "komedie",
    "getraind": "ongetraind",
    "vertrouwen": "wantrouwen",
    "waarheid": "valsheid",
    "lelijkheid": "schoonheid",
    "lelijk": "mooi",
    "ultiem": "naburig",
    "niet aanvaardbaar": "aanvaardbaar",
    "niet erkend": "erkend",
    "ongewijzigd": "gewijzigd",
    "ondubbelzinnig": "dubbelzinnig",
    "ongewapend": "gewapend",
    "onbevoegd": "gemachtigde",
    "onevenwichtig": "evenwichtige",
    "ongeloof": "geloof",
    "ongebonden": "gebonden",
    "onbreekbaar": "breekbaar",
    "ongebroken": "gebroken",
    "onveranderd": "veranderd",
    "oom": "tante",
    "ongewoon": "gemeenschappelijk",
    "onbekommerd": "bezorgd",
    "niet bevestigd": "bevestigd",
    "niet verbonden": "verbonden",
    "bewusteloosheid": "bewustzijn",
    "ongrondwettig": "grondwettelijk",
    "onconventionele": "conventioneel",
    "niet overtuigd": "overtuigd",
    "ontdekken": "deksel",
    "ongesneden": "besnoeiing",
    "onbepaald": "bepaald",
    "onderschatten": "overschatting",
    "ongewenst": "wenselijk",
    "overdreven": "ten gevolge",
    "onopgevoed": "geleerd",
    "niet verwacht": "verwacht",
    "onbekend": "vertrouwd",
    "ongunstig": "gunstig",
    "ontvouwen": "vouwen",
    "onverzoenlijk": "vergevensgezind",
    "ongelukkige": "gelukkig",
    "ondankbaar": "dankbaar",
    "ongelukkig": "lucky",
    "ongezond": "gezond",
    "onheilig": "heilig",
    "onverbeterd": "verbeterd",
    "onwetend": "op de hoogte",
    "onbewoond": "bewoond",
    "onbegrijpelijk": "begrijpelijk",
    "ongewild": "voorgenomen",
    "onopzettelijk": "opzettelijk",
    "niet geïnteresseerd": "geïnteresseerd",
    "oninteressant": "interessant",
    "unie": "scheiding",
    "unitaire": "federaal",
    "verenigd": "verdeeld",
    "onaardig": "soort",
    "onbeperkt": "beperkt",
    "ontsluiten": "slot",
    "ongemerkt": "gemarkeerd",
    "ongehuwd": "getrouwd",
    "ontmaskeren": "masker",
    "onbezet": "bezet",
    "officieus": "officieel",
    "zonder tegenstand": "gekant tegen",
    "onorthodoxe": "orthodox",
    "uitpakken": "pak",
    "onplezierig": "aangenaam",
    "onpopulair": "populair",
    "onvoorbereid": "bereid",
    "onproductieve": "produktief",
    "onbeschermd": "beschermde",
    "onuitgegeven": "gepubliceerd",
    "onbetwistbaar": "twijfelachtig",
    "onrealistische": "realistisch",
    "ongereguleerde": "gereguleerd",
    "niet verwant": "verwant",
    "onbetrouwbaar": "betrouwbaar",
    "onverkwikkelijk": "hartig",
    "onwetenschappelijk": "wetenschappelijk",
    "gewetenloos": "scrupuleus",
    "onzelfzuchtig": "egoïstisch",
    "onbestendig": "verrekend",
    "wankel": "stal",
    "onvast": "vast",
    "mislukt": "geslaagd",
    "niet gesteund": "ondersteunde",
    "niet sympathiek": "sympathiek",
    "onaangeroerd": "aangeraakt",
    "ongetraind": "getraind",
    "ongebruikelijk": "gebruikelijk",
    "onthullen": "sluier",
    "onbehoedzaam": "omzichtig",
    "onwillig": "gaarne",
    "onwil": "bereidwilligheid",
    "afwikkelen": "wind",
    "onwaardig": "waardig",
    "stedelijk": "landelijk",
    "gebruikelijk": "ongebruikelijk",
    "waardevol": "waardeloos",
    "sluier": "onthullen",
    "verbaal": "numeriek",
    "zege": "nederlaag",
    "deugdzaam": "slecht",
    "zichtbaarheid": "onzichtbaarheid",
    "zichtbaar": "onzichtbaar",
    "vocal": "instrumentaal",
    "vrijwillig": "onwillekeurig",
    "klinker": "medeklinker",
    "wekken": "slaap",
    "lopen": "rijden",
    "afnemen": "was-",
    "oorlog": "vrede",
    "omzichtig": "onbehoedzaam",
    "verspilling": "conserveren",
    "verkwistend": "zuinig",
    "was-": "afnemen",
    "zwak": "sterk",
    "zwakheid": "kracht",
    "rijkdom": "armoede",
    "gewichtloos": "gewichtig",
    "gewichtig": "gewichtloos",
    "fluisteren": "roepen",
    "wit": "zwart",
    "geheel": "gedeeltelijk",
    "breed": "smal",
    "verbreden": "smal",
    "gaarne": "onwillig",
    "bereidwilligheid": "onwil",
    "wind": "afwikkelen",
    "wijsheid": "dwaasheid",
    "wijs": "dwaas",
    "terugtrekken": "storting",
    "zorgen": "geruststellen",
    "waardeloos": "waardevol",
    "waardig": "onwaardig",
    "geschreven": "ongeschreven",
    "jong": "oud",
    "zenit": "nadir",
}
